@@ -358,6 +358,7 @@ def update_secondary_result_keys(
     (
         _,
         testcases_setname,
+        deployment_name_zsetname,
         _,
         tsname_project_total_success,
         running_platforms_setname,
@@ -378,8 +379,23 @@ def update_secondary_result_keys(
         test_name,
     )
     try:
+        rts.zadd(deployment_name_zsetname, {deployment_name: start_time_ms})
         if test_name is not None:
+            deployment_name_zsetname_testnames = (
+                deployment_name_zsetname
+                + "{}:deployment_name={}".format(
+                    deployment_name_zsetname, deployment_name
+                )
+            )
+            rts.zadd(deployment_name_zsetname_testnames, {test_name: start_time_ms})
             rts.sadd(testcases_setname, test_name)
+            testcases_zsetname = testcases_setname + ":zset"
+            rts.zadd(testcases_zsetname, {test_name: start_time_ms})
+            if "component" in metadata_tags:
+                testcases_zsetname_component = "{}:zset:component:{}".format(
+                    testcases_setname, metadata_tags["component"]
+                )
+                rts.zadd(testcases_zsetname_component, {test_name: start_time_ms})
         if "arch" in metadata_tags:
             rts.sadd(project_archs_setname, metadata_tags["arch"])
         if "os" in metadata_tags:
