@@ -279,6 +279,7 @@ def remote_db_spin(
             remote_run_result,
             results_dict,
             return_code,
+            _,
         ) = run_remote_client_tool(
             allowed_tools,
             None,
@@ -371,7 +372,7 @@ def db_error_artifacts(
         username,
         private_key,
         [
-            "zip -r {} {}".format(remote_zipfile, temporary_dir),
+            "zip -r {} {}/*".format(remote_zipfile, temporary_dir),
         ],
         db_ssh_port,
     )
