@@ -25,6 +25,9 @@ from redisbench_admin.run.args import PROFILE_FREQ
 from redisbench_admin.run.common import (
     get_start_time_vars,
     BENCHMARK_REPETITIONS,
+    CIRCLE_BUILD_URL,
+    CIRCLE_JOB,
+    WH_TOKEN,
     get_setup_type_and_primaries_count,
     common_properties_log,
     print_results_table_stdout,
@@ -41,6 +44,7 @@ from redisbench_admin.run.s3 import get_test_s3_bucket_path
 from redisbench_admin.run.ssh import ssh_pem_check
 from redisbench_admin.run_remote.args import TF_OVERRIDE_NAME
 from redisbench_admin.run_remote.consts import min_recommended_benchmark_duration
+from redisbench_admin.run_remote.notifications import generate_failure_notification
 from redisbench_admin.run_remote.remote_client import run_remote_client_tool
 from redisbench_admin.run_remote.remote_db import (
     remote_tmpdir_prune,
@@ -75,6 +79,7 @@ from redisbench_admin.utils.utils import (
     EC2_REGION,
 )
 
+from slack_sdk.webhook import WebhookClient
 
 # 7 days expire
 STALL_INFO_DAYS = 7
@@ -116,10 +121,60 @@ def run_remote_command_logic(args, project_name, project_version):
     profilers_enabled = args.enable_profilers
     keep_env_and_topo = args.keep_env_and_topo
 
-    if args.skip_env_vars_verify is False:
-        check_ec2_env()
+    if WH_TOKEN is not None:
+        webhook_notifications_active = True
 
-    redis_modules_check(local_module_files)
+    webhook_url = "https://hooks.slack.com/services/{}".format(WH_TOKEN)
+
+    ci_job_link = CIRCLE_BUILD_URL
+    ci_job_name = CIRCLE_JOB
+    failure_reason = ""
+    webhook_client_slack = None
+    if ci_job_link is None:
+        webhook_notifications_active = False
+        logging.warning(
+            "Disabling webhook notificaitons given CIRCLE_BUILD_URL is None"
+        )
+
+    if webhook_notifications_active is True:
+        logging.info(
+            "Detected where in a CI flow named {}. Here's the reference link: {}".format(
+                ci_job_name, ci_job_link
+            )
+        )
+        webhook_client_slack = WebhookClient(webhook_url)
+
+    if args.skip_env_vars_verify is False:
+        env_check_status, failure_reason = check_ec2_env()
+        if env_check_status is False:
+            if webhook_notifications_active:
+                generate_failure_notification(
+                    webhook_client_slack,
+                    ci_job_name,
+                    ci_job_link,
+                    failure_reason,
+                    tf_github_org,
+                    tf_github_repo,
+                    tf_github_branch,
+                    None,
+                )
+            exit(1)
+
+    module_check_status, error_message = redis_modules_check(local_module_files)
+    if module_check_status is False:
+        if webhook_notifications_active:
+            failure_reason = error_message
+            generate_failure_notification(
+                webhook_client_slack,
+                ci_job_name,
+                ci_job_link,
+                failure_reason,
+                tf_github_org,
+                tf_github_repo,
+                tf_github_branch,
+                None,
+            )
+        exit(1)
 
     common_properties_log(
         tf_bin_path,
@@ -148,10 +203,21 @@ def run_remote_command_logic(args, project_name, project_version):
     if benchmark_defs_result is False:
         return_code = 1
         if args.fail_fast:
-            logging.critical(
-                "Detected errors while preparing benchmark definitions. Exiting right away!"
-            )
-            exit(1)
+            failure_reason = "Detected errors while preparing benchmark definitions"
+            logging.critical("{}. Exiting right away!".format(failure_reason))
+            if webhook_notifications_active:
+                generate_failure_notification(
+                    webhook_client_slack,
+                    ci_job_name,
+                    ci_job_link,
+                    failure_reason,
+                    tf_github_org,
+                    tf_github_repo,
+                    tf_github_branch,
+                    None,
+                )
+
+            exit(return_code)
 
     remote_envs = {}
     dirname = "."
@@ -575,7 +641,7 @@ def run_remote_command_logic(args, project_name, project_version):
                                         else:
                                             https_link = (
                                                 generate_artifacts_table_grafana_redis(
-                                                    args,
+                                                    args.push_results_redistimeseries,
                                                     grafana_profile_dashboard,
                                                     profile_artifacts,
                                                     rts,
@@ -872,10 +938,13 @@ def run_remote_command_logic(args, project_name, project_version):
                                         tsname_project_total_failures,
                                     )
                                     return_code |= 1
-                                    logging.critical(
-                                        "Some unexpected exception was caught "
-                                        "during remote work. Failing test...."
+                                    failure_reason = "Some unexpected exception was caught during remote work on test named {}".format(
+                                        test_name
                                     )
+                                    logging.critical(
+                                        "{}. Failing test....".format(failure_reason)
+                                    )
+
                                     logging.critical(sys.exc_info()[0])
                                     print("-" * 60)
                                     traceback.print_exc(file=sys.stdout)
@@ -940,6 +1009,20 @@ def run_remote_command_logic(args, project_name, project_version):
                     EXPIRE_TIME_SECS_PROFILE_KEYS,
                     profile_markdown_str,
                 )
+
+    if return_code != 0 and webhook_notifications_active:
+        if failure_reason == "":
+            failure_reason = "Some unexpected exception was caught during remote work"
+        generate_failure_notification(
+            webhook_client_slack,
+            ci_job_name,
+            ci_job_link,
+            failure_reason,
+            tf_github_org,
+            tf_github_repo,
+            tf_github_branch,
+            None,
+        )
     exit(return_code)
 
 
